var NAVTREEINDEX21 =
{
"sparse__matrix__operations__solve_8hpp.html#afd116a080fa6ff167e6845f62c7d5229":[7,0,3,4,0,18,10],
"sparse__matrix__operations__solve_8hpp_source.html":[7,0,3,4,0,18],
"sparse__vector_8hpp.html":[7,0,3,4,1,3,9],
"sparse__vector_8hpp_source.html":[7,0,3,4,1,3,9],
"spmdm_8cpp.html":[7,0,2,0,37],
"spmdm_8cpp.html#a69e6d2aea1a54a57c32143a1f1a67443":[7,0,2,0,37,3],
"spmdm_8cpp.html#ad37b6388e659bcf40d9f782132321b4d":[7,0,2,0,37,1],
"spmdm_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,37,2],
"spmdm_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,37,0],
"spmdm_8cpp_source.html":[7,0,2,0,37],
"sse__blas_8hpp.html":[7,0,3,4,2,9],
"sse__blas_8hpp.html#a6c8d9882f41360d19f6615d06b31d4d3":[7,0,3,4,2,9,5],
"sse__blas_8hpp.html#a73ae3d8082d7379517630d6d64c1027c":[7,0,3,4,2,9,2],
"sse__blas_8hpp.html#a9b6f43691b2c9cb686f6941029255286":[7,0,3,4,2,9,0],
"sse__blas_8hpp.html#aabc74969faf4707d9278db966e30cc12":[7,0,3,4,2,9,3],
"sse__blas_8hpp.html#ad3daafc85712836c2406b771949df6d2":[7,0,3,4,2,9,1],
"sse__blas_8hpp.html#ae2a590df1af999034308d5583cca4020":[7,0,3,4,2,9,6],
"sse__blas_8hpp.html#ae89662d7ae3d65b0f2beca565c0c8a78":[7,0,3,4,2,9,4],
"sse__blas_8hpp_source.html":[7,0,3,4,2,9],
"sse__kernels_8hpp.html":[7,0,3,4,2,10],
"sse__kernels_8hpp.html#a186586aced1407e7106fd3f7f432f582":[7,0,3,4,2,10,4],
"sse__kernels_8hpp.html#a29a882acaad6a548f7fadf54598bdc42":[7,0,3,4,2,10,6],
"sse__kernels_8hpp.html#a537ac5e83bd3ad6927f1ab8389451ebd":[7,0,3,4,2,10,1],
"sse__kernels_8hpp.html#a9d7508e012aea146e6f35e08bc09c339":[7,0,3,4,2,10,8],
"sse__kernels_8hpp.html#aaa3af08473cb3a7f5116d54302c02d86":[7,0,3,4,2,10,2],
"sse__kernels_8hpp.html#ab1ca91eea2771be83df0a807951388d3":[7,0,3,4,2,10,3],
"sse__kernels_8hpp.html#acd0ccc877ddce3ae3ac5c4cb1393ccea":[7,0,3,4,2,10,5],
"sse__kernels_8hpp.html#ada3cb15238c1c502bde216d770949a00":[7,0,3,4,2,10,7],
"sse__kernels_8hpp.html#af014b25ce5cbd2c46fd1316de20429c2":[7,0,3,4,2,10,0],
"sse__kernels_8hpp_source.html":[7,0,3,4,2,10],
"start_8hpp.html":[7,0,3,10,6],
"start_8hpp.html#a16f0a75c983226dff5b259e7ff42b84e":[7,0,3,10,6,3],
"start_8hpp.html#a68603a1e1ca1bfb6d107831ba5096786":[7,0,3,10,6,0],
"start_8hpp.html#ac53fc8cc9836953dc87aaaaa56f382c2":[7,0,3,10,6,4],
"start_8hpp.html#ad0550a717e42c6cc277f971bcbbf040f":[7,0,3,10,6,1],
"start_8hpp.html#ae601425decc5f1a8763ab5272e9e492f":[7,0,3,10,6,2],
"start_8hpp.html#ae8d31d9bc99896631c0d727efb36f4a8":[7,0,3,10,6,5],
"start_8hpp_source.html":[7,0,3,10,6],
"stride_8hpp.html":[7,0,3,10,7],
"stride_8hpp.html#a09997870f4802fa5d4ac2c43cf4020d1":[7,0,3,10,7,0],
"stride_8hpp.html#a53a39f11907d9098e6f144c87998fe5e":[7,0,3,10,7,1],
"stride_8hpp.html#ace596004f16c075adbfcd329e6c60e91":[7,0,3,10,7,2],
"stride_8hpp_source.html":[7,0,3,10,7],
"struct_vienna_c_l_backend__impl.html":[6,0,13],
"struct_vienna_c_l_backend__impl.html#a4ac0646f1f1f1cdc2dc7d3b0899fd5b0":[6,0,13,0],
"struct_vienna_c_l_backend__impl.html#a4ba7ba11806c9207ea5bbd34bdca056b":[6,0,13,3],
"struct_vienna_c_l_backend__impl.html#a644a5eaaed66eb35c69d5f094a117b87":[6,0,13,2],
"struct_vienna_c_l_backend__impl.html#aa0382d3f1a5628c16c0fcb19faf6a7f6":[6,0,13,1],
"struct_vienna_c_l_c_u_d_a_backend__impl.html":[6,0,14],
"struct_vienna_c_l_host_backend__impl.html":[6,0,15],
"struct_vienna_c_l_host_scalar__impl.html":[6,0,16],
"struct_vienna_c_l_host_scalar__impl.html#a3a3cee55ea3498c0fd3ae6feef77bbdf":[6,0,16,1],
"struct_vienna_c_l_host_scalar__impl.html#a5017f1f1f2d1e9054c4a1b8f5f724211":[6,0,16,0],
"struct_vienna_c_l_host_scalar__impl.html#a7738a955cabcae09b84f455c1452b18f":[6,0,16,2],
"struct_vienna_c_l_matrix__impl.html":[6,0,17],
"struct_vienna_c_l_matrix__impl.html#a1a2591ff60fda8cb4e932ee8e4220e37":[6,0,17,10],
"struct_vienna_c_l_matrix__impl.html#a1bb3e3df3fe8b7befe40d30780779cb3":[6,0,17,11],
"struct_vienna_c_l_matrix__impl.html#a39776c9313e28c8c2ef265c3dfcded84":[6,0,17,0],
"struct_vienna_c_l_matrix__impl.html#a4103855d69aecbe85314a65700a02de3":[6,0,17,2],
"struct_vienna_c_l_matrix__impl.html#a56404bb5c6aaf0b64c53c89b2f6bc26a":[6,0,17,8],
"struct_vienna_c_l_matrix__impl.html#a83761810e0c5f91ea10ef3a4167b78d7":[6,0,17,6],
"struct_vienna_c_l_matrix__impl.html#a93e92d4c7b468cab69b0af60abe4bff0":[6,0,17,1],
"struct_vienna_c_l_matrix__impl.html#aa4e2d47a634e56bfb4184520792c7f64":[6,0,17,3],
"struct_vienna_c_l_matrix__impl.html#ab7815c208b9260ca0097909c1892fd0f":[6,0,17,9],
"struct_vienna_c_l_matrix__impl.html#ac2184140bcb059f7521857a6a5ef4362":[6,0,17,7],
"struct_vienna_c_l_matrix__impl.html#ad9b5572714d5760e0d6db0d5c4eacbc4":[6,0,17,5],
"struct_vienna_c_l_matrix__impl.html#ada5cf997e93ae6184f6fd1fb897a7387":[6,0,17,4],
"struct_vienna_c_l_matrix__impl.html#ae33a64dcfb8dfe7234dddc3270838bec":[6,0,17,12],
"struct_vienna_c_l_open_c_l_backend__impl.html":[6,0,18],
"struct_vienna_c_l_open_c_l_backend__impl.html#aa5f97c2ab6d7e2d75d0b378fb0014df7":[6,0,18,0],
"struct_vienna_c_l_scalar__impl.html":[6,0,19],
"struct_vienna_c_l_scalar__impl.html#a67d292f8863e566d0efb1f04708264d9":[6,0,19,0],
"struct_vienna_c_l_scalar__impl.html#a723dd4b75586c0d500b122db2458eb86":[6,0,19,2],
"struct_vienna_c_l_scalar__impl.html#a995d0345857ac7a6ad47e13021b9abb9":[6,0,19,1],
"struct_vienna_c_l_scalar__impl.html#af8a28d7c016b5c0b811c46a4bcb4b7c2":[6,0,19,3],
"struct_vienna_c_l_vector__impl.html":[6,0,20],
"struct_vienna_c_l_vector__impl.html#a2102cfe143f959a93374f4c1632f3b15":[6,0,20,5],
"struct_vienna_c_l_vector__impl.html#a277090fedfd0305e92a3f539a4f2d491":[6,0,20,2],
"struct_vienna_c_l_vector__impl.html#a3cf30b82794eaa7c0dac9f24060b0575":[6,0,20,1],
"struct_vienna_c_l_vector__impl.html#a843560fa56c6ad15a948b4253d9e0cb8":[6,0,20,3],
"struct_vienna_c_l_vector__impl.html#a8d5df6fb95c537becef8fe3f574945f9":[6,0,20,4],
"struct_vienna_c_l_vector__impl.html#ac9f74d13e9df7ce1332e99fca52bacc6":[6,0,20,0],
"structmatrix__maker.html":[6,0,2],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html":[6,0,3],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html#aeae2df6ae63978fa4d4e73c2097dfafc":[6,0,3,0],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4.html":[6,0,4],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4.html#aa4a25c0ef396500ec2f3800878b9bd8d":[6,0,4,0],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4.html#aa9d013b7ed65dd9dd385c0364b532ee1":[6,0,4,1],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html":[6,0,5],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html#adb3efe7c7b6a198fa64e8bbe3829e981":[6,0,5,1],
"structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html#ae9721615acd711ed356c8eb64db6c651":[6,0,5,0],
"structop__assign.html":[6,0,7],
"structop__minus__assign.html":[6,0,8],
"structop__plus__assign.html":[6,0,9],
"structs_8hpp.html":[7,0,3,4,1,1,5],
"structs_8hpp_source.html":[7,0,3,4,1,1,5],
"structtest_data.html":[6,0,10],
"structtest_data.html#a17b3748f5f39c787969812b2e8323d9c":[6,0,10,1],
"structtest_data.html#a221ded1c886a86b39e9fef197af7c58b":[6,0,10,5],
"structtest_data.html#a3c78d34e230ea1a828dceb27180ea700":[6,0,10,2],
"structtest_data.html#a634014dc338b61c038693642efabff47":[6,0,10,4],
"structtest_data.html#ad8e3394939d9f0e3e3f33abb01e28af4":[6,0,10,3],
"structtest_data.html#afbeac1b8842462a94a3204945bc54535":[6,0,10,0],
"structured-matrices_8cpp-example.html":[8,28],
"structviennacl_1_1backend_1_1cpu__ram_1_1detail_1_1array__deleter.html":[6,0,0,0,0,0,0],
"structviennacl_1_1backend_1_1cpu__ram_1_1detail_1_1array__deleter.html#abd0b5a4c3bfd43ef47b182fcc64b263b":[6,0,0,0,0,0,0,0],
"structviennacl_1_1backend_1_1cuda_1_1detail_1_1cuda__deleter.html":[6,0,0,0,1,0,0],
"structviennacl_1_1backend_1_1cuda_1_1detail_1_1cuda__deleter.html#a0f2e952a226c5a59a1c600801a4d0f11":[6,0,0,0,1,0,0,0],
"structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html":[6,0,0,0,2,0],
"structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html#a18f28abf42373dc78546ab0e6902433ca91eb2abbaa9857b3ec16f99e07412d05":[6,0,0,0,2,0,1],
"structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html#a40b6b039a7307633961b6ffb686a58ba":[6,0,0,0,2,0,0],
"structviennacl_1_1col__iteration.html":[6,0,0,14],
"structviennacl_1_1column__major.html":[6,0,0,15],
"structviennacl_1_1column__major.html#a4575031dc2c698a71b5cc9a4cf52dcec":[6,0,0,15,0],
"structviennacl_1_1column__major__tag.html":[6,0,0,16],
"structviennacl_1_1cuthill__mckee__tag.html":[6,0,0,24],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__architecture__t.html":[6,0,0,2,0,1,0],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__architecture__t.html#a3ebbe59beac2b73522ae94bb4d5ae692":[6,0,0,2,0,1,0,0],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__architecture__t.html#a613fa5e057653fac9ebec2eaddc7eefe":[6,0,0,2,0,1,0,1],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__name__t.html":[6,0,0,2,0,1,1],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__name__t.html#a474df92ad32565d465c0f21b9288ea64":[6,0,0,2,0,1,1,1],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__name__t.html#ab9007e31f640bc722d6e4c0b633e8209":[6,0,0,2,0,1,1,0],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__type__t.html":[6,0,0,2,0,1,2],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__type__t.html#ac62fc269d03a10c1fb9f3a37cb088191":[6,0,0,2,0,1,2,1],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__type__t.html#ad2db8f194d718c345278948056e94ba3":[6,0,0,2,0,1,2,0],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1expression__t.html":[6,0,0,2,0,1,3],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1expression__t.html#a14074e6f9ce708a32c548e8d4dc1f6e0":[6,0,0,2,0,1,3,0],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1expression__t.html#a5514b32aedea572dff4dc2957464e5f8":[6,0,0,2,0,1,3,1],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1type.html":[6,0,0,2,0,1,4],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1type.html#a83e2f1a5e34fe81400e03f88e0d871b8":[6,0,0,2,0,1,4,0],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1type.html#aecf3fc2b4be676e2c37fdeea4162adba":[6,0,0,2,0,1,4,1],
"structviennacl_1_1device__specific_1_1char__to__type.html":[6,0,0,2,6],
"structviennacl_1_1device__specific_1_1index__tuple.html":[6,0,0,2,9],
"structviennacl_1_1device__specific_1_1index__tuple.html#a155ce913118301cd9ae6b460e17ba6b5":[6,0,0,2,9,4],
"structviennacl_1_1device__specific_1_1index__tuple.html#a55129a0ddf002fe6184fc2e0f1e6c428":[6,0,0,2,9,3],
"structviennacl_1_1device__specific_1_1index__tuple.html#aac82b1c95dd3e2295fd86f49550a9766":[6,0,0,2,9,5],
"structviennacl_1_1device__specific_1_1index__tuple.html#ac9cf988d8de3e2d689b6a1a7f997e301":[6,0,0,2,9,1],
"structviennacl_1_1device__specific_1_1index__tuple.html#ae900addc9a3b6f60109a39859a76c0d6":[6,0,0,2,9,0],
"structviennacl_1_1device__specific_1_1index__tuple.html#af73d1e80cf6b39591f6cb7ad28225000":[6,0,0,2,9,2],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base.html":[6,0,0,2,21,0],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base.html#a12be18214880552ff3d1ec024ea80452":[6,0,0,2,21,0,0],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base1_d.html":[6,0,0,2,21,1],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base1_d.html#ae33d7a5f0041b8329be3c98ef0ceca99":[6,0,0,2,21,1,0],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base2_d.html":[6,0,0,2,21,2],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base2_d.html#a57631eb2afd669c6843f50de684ab040":[6,0,0,2,21,2,0],
"structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html":[6,0,0,2,21,3],
"structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html#a14cdd5497bcfaf219e803e83218b6b1c":[6,0,0,2,21,3,2],
"structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html#a5a38c1848cc1f189b2604edfa1755307":[6,0,0,2,21,3,3],
"structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html#a777a23283e4ebf4ac3f0c050089a10b2":[6,0,0,2,21,3,1],
"structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html#ad2ff5d228c1ea839eea9e218bfe2df76":[6,0,0,2,21,3,0],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html":[6,0,0,2,31],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a29b6bf185463a1cd91e5f3134c25171a":[6,0,0,2,31,0],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a4d24a7a45929418fabfd8ffd110ff243":[6,0,0,2,31,6],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a52b9382dea07e03094b23d288f73755b":[6,0,0,2,31,8],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a52bfcc28584cd62d9619f696954752df":[6,0,0,2,31,4],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a8e137da60bb9fa5dced7354e6a16d5a9":[6,0,0,2,31,10],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a9b3d791ae84fbc96c75b63fd50c4eac7":[6,0,0,2,31,1],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#aa3fc8dd92315ea4d11feef954f05944b":[6,0,0,2,31,7],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#ab718cdd575d19f433b86e4c64c571213":[6,0,0,2,31,5],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#ace1ec7dae07b9e82014e68c058c03d66":[6,0,0,2,31,2],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#ad3baeaf2debc82140b0c94019c3ed4bc":[6,0,0,2,31,9],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html#af26921686a03f05462e889d6dcbe5415":[6,0,0,2,31,3],
"structviennacl_1_1device__specific_1_1reduction__parameters.html":[6,0,0,2,33],
"structviennacl_1_1device__specific_1_1reduction__parameters.html#a539b1a9c7d202a007c70b4bc03ba1232":[6,0,0,2,33,2],
"structviennacl_1_1device__specific_1_1reduction__parameters.html#a9e1dd78718fc464c39afc7b2c3547179":[6,0,0,2,33,1],
"structviennacl_1_1device__specific_1_1reduction__parameters.html#abf01b27ceb1be3066c5436d08c51a34e":[6,0,0,2,33,0],
"structviennacl_1_1device__specific_1_1row__wise__reduction__parameters.html":[6,0,0,2,35],
"structviennacl_1_1device__specific_1_1row__wise__reduction__parameters.html#a18afc5821009c52835368d9f5ff37484":[6,0,0,2,35,2],
"structviennacl_1_1device__specific_1_1row__wise__reduction__parameters.html#a64f134200cb1d4f43ad25126cfd9ddcc":[6,0,0,2,35,0],
"structviennacl_1_1device__specific_1_1row__wise__reduction__parameters.html#af86872e2bbed3201309370e46a2db318":[6,0,0,2,35,1],
"structviennacl_1_1device__specific_1_1template__base_1_1loop__body__base.html":[6,0,0,2,39,1],
"structviennacl_1_1device__specific_1_1template__base_1_1loop__body__base.html#ac4b366068022cfe6b17842b385f27759":[6,0,0,2,39,1,1],
"structviennacl_1_1device__specific_1_1template__base_1_1loop__body__base.html#af5b5309be6a8cbbf1c45a8955c89ac7e":[6,0,0,2,39,1,0],
"structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html":[6,0,0,2,39,2],
"structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#a0013ca39734fd5a1b8110e8710a178c2":[6,0,0,2,39,2,2],
"structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#a34057720aa9dae4bf9edfa5028e486ea":[6,0,0,2,39,2,3],
"structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#ad8356d07e99690dafe3d12041cbcd169":[6,0,0,2,39,2,1],
"structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#ae4f54038c3465b5fcd440c68bd1d0701":[6,0,0,2,39,2,0],
"structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#af859aa51f8a2c20e654f63fdb34bb5b6":[6,0,0,2,39,2,4],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type.html":[6,0,0,2,2,0],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01char_01_4.html":[6,0,0,2,2,1],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01double_01_4.html":[6,0,0,2,2,2],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01float_01_4.html":[6,0,0,2,2,3],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01int_01_4.html":[6,0,0,2,2,4],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01long_01_4.html":[6,0,0,2,2,5],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01short_01_4.html":[6,0,0,2,2,6],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01char_01_4.html":[6,0,0,2,2,7],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01int_01_4.html":[6,0,0,2,2,8],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01long_01_4.html":[6,0,0,2,2,9],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01short_01_4.html":[6,0,0,2,2,10],
"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html":[6,0,0,2,2,11],
"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html#a2eeea82437fdfca56530a290b4fd3237":[6,0,0,2,2,11,1],
"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html#a51aba73af223f30ff44068b7cf58a062":[6,0,0,2,2,11,0],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html":[6,0,0,2,2,12],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html#a49dda80f9c881ef0044168c7391680a9":[6,0,0,2,2,12,1],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html#a94637ceae517b8f5ed07c3859a19a1cb":[6,0,0,2,2,12,0],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html":[6,0,0,2,2,13],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html#a32ec16c83f6accf8a4a3b4c3fa687ad3":[6,0,0,2,2,13,0],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html#af6a1615f03eb4e06f24a42cfb39d119d":[6,0,0,2,2,13,1],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html":[6,0,0,2,2,14],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html#a04b314dab25469a07e2c1815b2278ba7":[6,0,0,2,2,14,0],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html#a591aa73f27eef9ce3e0353213d81939e":[6,0,0,2,2,14,1],
"structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html":[6,0,0,2,2,15],
"structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html#a5ca56050bcedeca039469d522da71bbda0de8ea24b6c4b31cf8e314f4870c363f":[6,0,0,2,2,15,0],
"structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html":[6,0,0,2,2,16],
"structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html#a0947d587134892dc795ad41f21c7cfe4a11fbe8b012f0400b71192e0961470798":[6,0,0,2,2,16,0],
"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html":[6,0,0,2,2,18],
"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html#a326c5de9c7d5e5956df21d9c51fae443":[6,0,0,2,2,18,1],
"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html#a3ae543b5c47f099a79a66f7ccb0cc251":[6,0,0,2,2,18,0],
"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html":[6,0,0,2,2,19],
"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html#a4e33ade1964ba6d5240e3e83221677a8":[6,0,0,2,2,19,0],
"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html#a7258a1cdc617a7cf3264f27650a324cc":[6,0,0,2,2,19,1],
"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html":[6,0,0,2,2,20],
"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html#a13c76e80d8d2476f7296d3a5eb9964a7":[6,0,0,2,2,20,0],
"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html#afcf06528f70ce5af6cb12a735926c3e3":[6,0,0,2,2,20,1],
"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html":[6,0,0,2,2,21],
"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#aa25e886c6f7ea396dd3661ba22848d6c":[6,0,0,2,2,21,0],
"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#ab8aaa1aa22a53ac8a37b7bd39f6b9ed0":[6,0,0,2,2,21,1],
"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#ac12e6bc19b07d4e29130b1b631ae18e0":[6,0,0,2,2,21,2],
"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#af6d99b4ee32ae88155cd1bf449a2989b":[6,0,0,2,2,21,3],
"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html":[6,0,0,2,2,22],
"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html#a6f788402ff5b7c320d4925a099dc0d68":[6,0,0,2,2,22,0],
"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html#ae2f3250fd7f8dc1a52cdb5a0ee85080b":[6,0,0,2,2,22,1],
"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html":[6,0,0,2,2,23],
"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html#a042219c4692be2d1e62c31c6bf9ef43a":[6,0,0,2,2,23,0],
"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html#abc0b675a97030f92bf8ef3aed0274c56":[6,0,0,2,2,23,1],
"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html":[6,0,0,2,2,24],
"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html#a3f999e9195f1917902bfcabca58aa401":[6,0,0,2,2,24,1],
"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html#ac1c23304658b2f8be17c0f706817a592":[6,0,0,2,2,24,0],
"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html":[6,0,0,2,2,25],
"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#a8859a3effbc408c887156a3270377362":[6,0,0,2,2,25,1],
"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#afa684b874dcbd93cecc20beaf5d5300b":[6,0,0,2,2,25,0],
"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html":[6,0,0,2,2,26],
"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#ab9e9f54c99ee5c4fa7b03c86fb3c7bac":[6,0,0,2,2,26,0],
"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#acd76d9e773edd4ce64ab535898b7ee2e":[6,0,0,2,2,26,1],
"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html":[6,0,0,2,2,27],
"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a0be523ad58edf147b3cd3adfdd58f621":[6,0,0,2,2,27,1],
"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a7bf16956f06a6bbf04e1ed2f86e42f3f":[6,0,0,2,2,27,0],
"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html":[6,0,0,2,2,28],
"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#a19297e53a833c520335ecc5320807d2c":[6,0,0,2,2,28,1],
"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#ad81e702da882bd123ace4a495da13df5":[6,0,0,2,2,28,0],
"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html":[6,0,0,2,2,29],
"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30737a886c21ee6e8b31b47f812e2312":[6,0,0,2,2,29,1],
"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30b3642c00ccbf41e80ddbe1c8857112":[6,0,0,2,2,29,0],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html":[6,0,0,2,2,30],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html":[6,0,0,2,2,31],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html":[6,0,0,2,2,32],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html":[6,0,0,2,2,33],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html":[6,0,0,2,2,34],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html":[6,0,0,2,2,35]
};
